@@ -5,13 +5,13 @@ require 'roodi/checks/class_line_count_check'
 require 'roodi/checks/class_name_check'
 require 'roodi/checks/class_variable_check'
 require 'roodi/checks/control_coupling_check'
+require 'roodi/checks/core_method_override_check'
 require 'roodi/checks/cyclomatic_complexity_block_check'
 require 'roodi/checks/cyclomatic_complexity_method_check'
 require 'roodi/checks/empty_rescue_body_check'
 require 'roodi/checks/for_loop_check'
 require 'roodi/checks/method_line_count_check'
 require 'roodi/checks/method_name_check'
-require 'roodi/checks/missing_foreign_key_index_check'
 require 'roodi/checks/module_line_count_check'
 require 'roodi/checks/module_name_check'
 require 'roodi/checks/npath_complexity_method_check'
