@@ -1,3 +1,6 @@
 $LOAD_PATH.unshift(File.expand_path(File.dirname(__FILE__) + "/../lib"))
 require 'roodi'
-require 'spec'
+require 'rspec'
+require 'coveralls'
+Coveralls.wear!
+
